==> e107-0.7.20.tbz: www/e107/e107_plugins/linkwords/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Steve Dunstan 2001-2002
|     http://e107.org
|     jalist@e107.org
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/linkwords/languages/English.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
	
define("LWLAN_1", "Field(s) left blank.");
define("LWLAN_2", "Link word saved.");
define("LWLAN_3", "Link word updated.");
define("LWLAN_4", "No link words defined yet.");
define("LWLAN_5", "Words");
define("LWLAN_6", "Link");
define("LWLAN_7", "Active?");
define("LWLAN_8", "Options");
define("LWLAN_9", "yes");
define("LWLAN_10", "no");
define("LWLAN_11", "Existing Linkwords");
define("LWLAN_12", "Yes");
define("LWLAN_13", "No");
define("LWLAN_14", "Submit LinkWord");
define("LWLAN_15", "Update LinkWord");
define("LWLAN_16", "Edit");
define("LWLAN_17", "Delete");
define("LWLAN_18", "Are you sure you want to delete this linkword?");
define("LWLAN_19", "Linkword deleted.");
define("LWLAN_20", "Unable to find that linkword entry.");
define("LWLAN_21", "Word to autolink (or comma-separated list of words)");
define("LWLAN_22", "Activate?");
define("LWLAN_23", "Linkwords Administration");
define("LWLAN_24", "Manage Words");
define("LWLAN_25", "Options");
define("LWLAN_26", "Areas in which to enable linkwords");
define("LWLAN_27", "This is the 'context' of the displayed text");
define("LWLAN_28", "Pages on which to disable linkwords");
define("LWLAN_29", "Same format as menu visibility control. One match per line. Specify a partial or complete URL. End with '!' for exact match of the end part of the link");
define("LWLAN_30", "Save options");
define("LWLAN_31", "Add/edit linkword");
define("LWLAN_32", "Linkword Options");
define("LWLAN_33", 'Title areas');
define("LWLAN_34", 'Item summaries');
define("LWLAN_35", 'Body text');
define("LWLAN_36", 'Descriptions (links etc)');
define("LWLAN_37", 'Legacy areas');
define("LWLAN_38", 'Clickable links');
define("LWLAN_39", 'Unprocessed text');
define("LWLAN_40", 'User-entered titles (e.g. forum)');
define("LWLAN_41", 'User-entered body text (e.g. forum)');


define("LWLANINS_1", "Linkwords");
define("LWLANINS_2", "This plugin will link specified words with a defined link");
define("LWLANINS_3", "Configure LinkWords");
define("LWLANINS_4", "To configure please click on the link in the plugins section of the admin front page");

?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/linkwords/languages/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Copyright (C) 2001-2002 Steve Dunstan (jalist@e107.org)
|     Copyright (C) 2008-2010 e107 Inc (e107.org)
|
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/linkwords/languages/English.php $
|     $Revision: 11678 $
|     $Id: English.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
	
define("LWLAN_1", "Field(s) left blank.");
define("LWLAN_2", "Link word saved.");
define("LWLAN_3", "Link word updated.");
define("LWLAN_4", "No link words defined yet.");
define("LWLAN_5", "Words");
define("LWLAN_6", "Link");
define("LWLAN_7", "Active?");
define("LWLAN_8", "Options");
define("LWLAN_9", "yes");
define("LWLAN_10", "no");
define("LWLAN_11", "Existing Linkwords");
define("LWLAN_12", "Yes");
define("LWLAN_13", "No");
define("LWLAN_14", "Submit LinkWord");
define("LWLAN_15", "Update LinkWord");
define("LWLAN_16", "Edit");
define("LWLAN_17", "Delete");
define("LWLAN_18", "Are you sure you want to delete this linkword?");
define("LWLAN_19", "Linkword deleted.");
define("LWLAN_20", "Unable to find that linkword entry.");
define("LWLAN_21", "Word to autolink (or comma-separated list of words)");
define("LWLAN_22", "Activate?");
define("LWLAN_23", "Linkwords Administration");
define("LWLAN_24", "Manage Words");
define("LWLAN_25", "Options");
define("LWLAN_26", "Areas in which to enable linkwords");
define("LWLAN_27", "This is the 'context' of the displayed text");
define("LWLAN_28", "Pages on which to disable linkwords");
define("LWLAN_29", "Same format as menu visibility control. One match per line. Specify a partial or complete URL. End with '!' for exact match of the end part of the link");
define("LWLAN_30", "Save options");
define("LWLAN_31", "Add/edit linkword");
define("LWLAN_32", "Linkword Options");
define("LWLAN_33", 'Title areas');
define("LWLAN_34", 'Item summaries');
define("LWLAN_35", 'Body text');
define("LWLAN_36", 'Descriptions (links etc)');
define("LWLAN_37", 'Legacy areas');
define("LWLAN_38", 'Clickable links');
define("LWLAN_39", 'Unprocessed text');
define("LWLAN_40", 'User-entered titles (e.g. forum)');
define("LWLAN_41", 'User-entered body text (e.g. forum)');


define("LWLANINS_1", "Linkwords");
define("LWLANINS_2", "This plugin will link specified words with a defined link");
define("LWLANINS_3", "Configure LinkWords");
define("LWLANINS_4", "To configure please click on the link in the plugins section of the admin front page");

?>
